module.exports = {
    rules: {
        // Possible Errors
        'for-direction': 2,
        'getter-return': 2,
        'no-compare-neg-zero': 2,
        'no-cond-assign': [2, 'always'],
        'no-console': 2,
        'no-constant-condition': 2,
        'no-control-regex': 2,
        'no-debugger': 2,
        'no-dupe-args': 2,
        'no-dupe-keys': 2,
        'no-duplicate-case': 2,
        'no-empty': 2,
        'no-empty-character-class': 2,
        'no-ex-assign': 2,
        'no-extra-boolean-cast': 2,
        'no-extra-parens': [2, 'all', {
            nestedBinaryExpressions: false,
            ignoreJSX: 'multi-line',
            enforceForArrowConditionals: false
        }],
        'no-extra-semi': 2,
        'no-func-assign': 2,
        'no-inner-declarations': 2,
        'no-invalid-regexp': 2,
        'no-irregular-whitespace': 2,
        'no-obj-calls': 2,
        'no-regex-spaces': 2,
        'no-sparse-arrays': 2,
        'no-unexpected-multiline': 2,
        'no-unreachable': 2,
        'no-unsafe-finally': 2,
        'no-unsafe-negation': 2,
        'use-isnan': 2,
        'valid-typeof': [2, { requireStringLiterals: true }],

        // Best Practices
        'array-callback-return': 2,
        'class-methods-use-this': 2,
        'complexity': [2, { max: 8 }],
        'consistent-return': [2, { treatUndefinedAsUnspecified: true }],
        'curly': [2, 'all'],
        'dot-location': [2, 'property'],
        'dot-notation': 2,
        'eqeqeq': 2,
        'no-alert': 2,
        'no-caller': 2,
        'no-case-declarations': 2,
        'no-else-return': 2,
        'no-empty-function': 2,
        'no-empty-pattern': 2,
        'no-eval': 2,
        'no-extend-native': 2,
        'no-extra-bind': 2,
        'no-fallthrough': 2,
        'no-floating-decimal': 2,
        'no-global-assign': 2,
        'no-implied-eval': 2,
        'no-invalid-this': 2,
        'no-labels': 2,
        'no-lone-blocks': 2,
        'no-multi-spaces': 2,
        'no-multi-str': 2,
        'no-new': 2,
        'no-new-func': 2,
        'no-new-wrappers': 2,
        'no-octal': 2,
        'no-octal-escape': 2,
        'no-proto': 2,
        'no-redeclare': 2,
        'no-return-await': 2,
        'no-script-url': 2,
        'no-self-assign': [2, { props: true }],
        'no-self-compare': 2,
        'no-sequences': 2,
        'no-throw-literal': 2,
        'no-unmodified-loop-condition': 2,
        'no-unused-expressions': 2,
        'no-unused-labels': 2,
        'no-useless-call': 2,
        'no-useless-concat': 2,
        'no-useless-escape': 2,
        'no-useless-return': 2,
        'no-void': 2,
        'no-with': 2,
        'prefer-promise-reject-errors': 2,
        'radix': 2,
        'require-await': 2,
        'yoda': 2,

        // Strict Mode
        'strict': [2, 'never'],

        // Variables
        'no-delete-var': 2,
        'no-label-var': 2,
        'no-shadow': [2, { builtinGlobals: true }],
        'no-shadow-restricted-names': 2,
        'no-undef': 2,
        'no-unused-vars': 2,
        'no-use-before-define': 2,

        // Node.js and CommonJS
        'global-require': 2,
        'no-buffer-constructor': 2,
        'no-mixed-requires': 2,
        'no-new-require': 2,
        'no-path-concat': 2,
        'no-sync': 2,

        // Stylistic Issues
        'array-bracket-newline': [2, 'consistent'],
        'array-bracket-spacing': 2,
        'block-spacing': 2,
        'brace-style': 2,
        'camelcase': 2,
        'comma-dangle': 2,
        'comma-spacing': 2,
        'comma-style': 2,
        'computed-property-spacing': 2,
        'eol-last': 2,
        'func-call-spacing': 2,
        'function-paren-newline': 2,
        'id-length': [2, {
            min: 1,
            max: 32
        }],
        'implicit-arrow-linebreak': 2,
        'indent': [2, 4, { SwitchCase: 1 }],
        'jsx-quotes': [2, 'prefer-single'],
        'key-spacing': 2,
        'keyword-spacing': 2,
        'lines-between-class-members': 2,
        'max-len': 2,
        'max-lines': [2, 500],
        'max-params': [2, 8],
        'max-statements': [2, 16],
        'max-statements-per-line': 2,
        'multiline-ternary': [2, 'always-multiline'],
        'new-cap': 2,
        'new-parens': 2,
        'newline-per-chained-call': [2, { ignoreChainWithDepth: 3 }],
        'no-array-constructor': 2,
        'no-bitwise': 2,
        'no-continue': 2,
        'no-lonely-if': 2,
        'no-mixed-operators': 2,
        'no-mixed-spaces-and-tabs': 2,
        'no-multi-assign': 2,
        'no-multiple-empty-lines': [2, {
            max: 1,
            maxBOF: 0
        }],
        'no-negated-condition': 2,
        'no-nested-ternary': 2,
        'no-new-object': 2,
        'no-tabs': 2,
        'no-trailing-spaces': 2,
        'no-underscore-dangle': 2,
        'no-unneeded-ternary': [2, { defaultAssignment: false }],
        'no-whitespace-before-property': 2,
        'object-curly-newline': [2, { consistent: true }],
        'object-curly-spacing': [2, 'always'],
        'object-property-newline': 2,
        'one-var': [2, 'never'],
        'operator-assignment': 2,
        'operator-linebreak': [2, 'before'],
        'padded-blocks': [2, {
            blocks: 'never',
            classes: 'always',
            switches: 'never'
        }],
        'quote-props': [2, 'consistent-as-needed'],
        'quotes': [2, 'single', {
            avoidEscape: true,
            allowTemplateLiterals: true
        }],
        'semi': 2,
        'semi-spacing': 2,
        'semi-style': 2,
        'space-before-blocks': 2,
        'space-before-function-paren': [2, 'never'],
        'space-in-parens': 2,
        'space-infix-ops': 2,
        'space-unary-ops': 2,
        'spaced-comment': 2,
        'switch-colon-spacing': 2,
        'template-tag-spacing': 2,
        'unicode-bom': 2,
        'wrap-regex': 2
    }
};
